# Entropz subpackage developing notes

These notes are used for keeping track of ToDos and porting information.

## Matlab references
- entlb_vbmc: [entlb_vbmc.m](https://github.com/acerbilab/vbmc/blob/master/ent/entlb_vbmc.m)
- entmc_vbmc: [entmc_vbmc.m](https://github.com/acerbilab/vbmc/blob/master/ent/entmc_vbmc.m)
